betty.extension.gramps package - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.gramps package

## Submodules

- betty.extension.gramps.config module
  - `FamilyTreeConfiguration`
    - `FamilyTreeConfiguration.__init__()`
    - `FamilyTreeConfiguration.dump()`
    - `FamilyTreeConfiguration.file_path`
    - `FamilyTreeConfiguration.load()`
    - `FamilyTreeConfiguration.update()`
  - `FamilyTreeConfigurationSequence`
    - `FamilyTreeConfigurationSequence.load_item()`
  - `GrampsConfiguration`
    - `GrampsConfiguration.__init__()`
    - `GrampsConfiguration.dump()`
    - `GrampsConfiguration.family_trees`
    - `GrampsConfiguration.load()`
    - `GrampsConfiguration.update()`

## Module contents

Integrate Betty with Gramps.

final class betty.extension.gramps.Gramps

  Bases: `ConfigurableExtension`[`GrampsConfiguration`]

  Integrate Betty with Gramps.

  classmethod default_configuration() → GrampsConfiguration

    Get this extension’s default configuration.

  classmethod plugin_description() → Localizable

    Get the human-readable long plugin description.

  classmethod plugin_id() → PluginId

    Get the plugin ID.

    IDs are unique per plugin type: - A plugin repository MUST at most have a single plugin for any ID. - Different plugin repositories MAY each have a plugin with the same ID.

  classmethod plugin_label() → Localizable

    Get the human-readable short plugin label.

  register_event_handlers(registry: EventHandlerRegistry) → None

    Register event handlers with the project.